/*
 *	libetm-0.3 / error.c - Copyright (C) Emmanuel Thomas-Maurin 2008-2009-2010
 * 	manutm007@gmail.com
 *
 *	- error handling -
 *
 * 	This program is free software: you can redistribute it and/or modify
 * 	it under the terms of the GNU General Public License as published by
 * 	the Free Software Foundation, either version 3 of the License, or
 * 	(at your option) any later version.
 *
 * 	This program is distributed in the hope that it will be useful,
 * 	but WITHOUT ANY WARRANTY; without even the implied warranty of
 * 	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * 	GNU General Public License for more details.
 *
 * 	You should have received a copy of the GNU General Public License
 * 	along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */

#include <stdlib.h>
#include <stdio.h>
#include "libetm.h"

/*
 * "fatal" error handler for lib that will call big_error() function defined in
 * app so that appropiate behaviour can be choosen (would it be better to implement a variadic func?)
 */
int big_error_in_lib(lib_error_code error_code, const char *str)
{
	/* only call big_error() in app */
	/*if (error_code > LIB_NO_ERROR && error_code < LIB_LASTERRORCODE)
		fprintf(stderr, "FATAL ERROR: Libetm:%s: %s\n", str, get_lib_error_str(error_code));*/
	big_error(error_code, str, "", "", "");
	return error_code;
}

const char *get_lib_error_str(lib_error_code error_code)
{
	/*
	 * *** make sure this array matches the lib errors enum ***
	 */
	static char *lib_error_str[] = {
		"No error",
		"Out of memory",
		"Zero requested size",
		/*"Negative requested size",*/
		"Null destination string",
		"Source string = destination string",
		"Strings overlap",
		"Attempting to free a null pointer",
		"No error"
	};

	if (error_code <= LIB_LASTERRORCODE)
		return (const char *)lib_error_str[error_code];
	else
		return "";
}
